[![Python 3](https://pyup.io/repos/github/geokrety/geokrety-api-models/python-3-shield.svg)](https://pyup.io/repos/github/geokrety/geokrety-api-models/)
[![Updates](https://pyup.io/repos/github/geokrety/geokrety-api-models/shield.svg)](https://pyup.io/repos/github/geokrety/geokrety-api-models/)
[![Codacy Badge](https://api.codacy.com/project/badge/Grade/f9a7080046074fa6b084f14f9bb0a91c)](https://www.codacy.com/app/GeoKrety/geokrety-api-models?utm_source=github.com&amp;utm_medium=referral&amp;utm_content=geokrety/geokrety-api-models&amp;utm_campaign=Badge_Grade)


# GeoKrety API Models

This contains ORM files for the [GeoKrety API project](https://github.com/geokrety/geokrety-api)
or other dependent subprojects such as FAAS functions.
